@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003, 2007 GraphicsMagick Group
+  Copyright (C) 2003, 2007, 2009 GraphicsMagick Group
  
   This program is covered by multiple licenses, which are described in
   Copyright.txt. You should have received a copy of Copyright.txt with this
@@ -27,7 +27,7 @@ extern "C" {
   magick_uint64_t --                          0 to 18,446,744,073,709,551,615
 */
 
-#if defined(WIN32) && !defined(__MINGW32__) || defined (_CH_)
+#if (defined(WIN32) || defined(WIN64)) && !defined(__MINGW32__) || defined (_CH_)
 
   /* The following typedefs are used for WIN32 */
   typedef signed char   magick_int8_t;
@@ -37,7 +37,9 @@ extern "C" {
   typedef unsigned short magick_uint16_t;
 
   typedef signed int  magick_int32_t;
+#define MAGICK_INT32_F ""
   typedef unsigned int magick_uint32_t;
+#define MAGICK_UINT32_F ""
 
 #  if defined(_CH_)
 #  include <stdint.h>
@@ -45,11 +47,19 @@ extern "C" {
   typedef uint64_t magick_uint64_t;
 #  else
   typedef signed __int64  magick_int64_t;
+#define MAGICK_INT64_F "I64"
   typedef unsigned __int64 magick_uint64_t;
+#define MAGICK_UINT64_F "I64"
 #  endif
 
   typedef magick_uint64_t magick_uintmax_t;
+
+#if defined(WIN32)
   typedef unsigned long magick_uintptr_t;
+#elif defined(WIN64)
+  /* WIN64 uses the LLP64 model */
+  typedef unsigned long long magick_uintptr_t;
+#endif
 
 #else
 
@@ -61,18 +71,26 @@ extern "C" {
   typedef unsigned short magick_uint16_t;
 
   typedef signed int  magick_int32_t;
+#define MAGICK_INT32_F ""
   typedef unsigned int magick_uint32_t;
+#define MAGICK_UINT32_F ""
 
   typedef signed long  magick_int64_t;
+#define MAGICK_INT64_F "l"
   typedef unsigned long magick_uint64_t;
+#define MAGICK_UINT64_F "l"
 
   typedef unsigned long magick_uintmax_t;
+#define MAGICK_UINTMAX_F "l"
+
   typedef unsigned long magick_uintptr_t;
+#define MAGICK_UINTPTR_F "l"
 
 #endif
 
   /* 64-bit file and blob offset type */
   typedef magick_int64_t magick_off_t;
+#define MAGICK_OFF_F MAGICK_INT64_F
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
